==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/MicrophoneLinesSlash.md <==
# MicrophoneLinesSlash


```text
fontawesome-6/Solid/MicrophoneLinesSlash
```

```text
include('fontawesome-6/Solid/MicrophoneLinesSlash')
```



| Illustration | MicrophoneLinesSlash |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/MicrophoneLinesSlash.png) | ![illustration for MicrophoneLinesSlash](../../fontawesome-6/Solid/MicrophoneLinesSlash.Local.png) |




## MicrophoneLinesSlash

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element MicrophoneLinesSlash
include('fontawesome-6/Solid/MicrophoneLinesSlash')

' renders the element
MicrophoneLinesSlash('MicrophoneLinesSlash', 'Microphone Lines Slash', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element MicrophoneLinesSlash
include('fontawesome-6/Solid/MicrophoneLinesSlash')

' renders the element
MicrophoneLinesSlash('MicrophoneLinesSlash', 'Microphone Lines Slash', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/MicrophoneLinesSlash.md <==
# MicrophoneLinesSlash


```text
fontawesome-6/Solid/MicrophoneLinesSlash
```

```text
include('fontawesome-6/Solid/MicrophoneLinesSlash')
```



| Illustration | MicrophoneLinesSlash |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/MicrophoneLinesSlash.png) | ![illustration for MicrophoneLinesSlash](../../fontawesome-6/Solid/MicrophoneLinesSlash.Local.png) |




## MicrophoneLinesSlash

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element MicrophoneLinesSlash
include('fontawesome-6/Solid/MicrophoneLinesSlash')

' renders the element
MicrophoneLinesSlash('MicrophoneLinesSlash', 'Microphone Lines Slash', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element MicrophoneLinesSlash
include('fontawesome-6/Solid/MicrophoneLinesSlash')

' renders the element
MicrophoneLinesSlash('MicrophoneLinesSlash', 'Microphone Lines Slash', 'an optional tech label', 'an optional description')
@enduml
```
